```python
AccountLinking = Dict[str, Any]
Screen = Dict[str, Any]
AudioPlayer = Dict[str, Any]
```

<br/>

::: aliceio.types.interfaces.Interfaces
    handler: python
    options:
      members:
        - account_linking
        - screen
        - audio_player
